OC.L10N.register(
    "mail",
    {
    "Mail" : "E-pasts",
    "Auto detect failed. Please use manual mode." : "Automātiski noteikt neizdevās. Lūdzu, izmantojiet manuālo režīmu.",
    "Creating account failed: " : "Konta izveide neizdevās:",
    "Name" : "Nosaukums",
    "Mail Address" : "E-pasta adrese",
    "Password" : "Parole",
    "IMAP Host" : "IMAP serveris",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Host" : "SMTP serveris",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Add mail account" : "Pievienot e-pasta kontu",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Select account" : "Izvēlieties kontu",
    "Copy" : "Kopēt",
    "Subject" : "Temats",
    "Add attachment from Files" : "Pievienot pielikumu no failiem",
    "Sending …" : "Sūta …",
    "Go back" : "Atpakaļ",
    "Retry" : "Mēģināt vēlreiz",
    "Message sent!" : "Vēstule aizsūtīta!",
    "Send" : "Sūtīt",
    "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
    "Delete" : "Dzēst",
    "Reply" : "Atbildēt",
    "Forward" : "Turpināt",
    "Import into calendar" : "Importēt kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tiek bloķēti, lai aizsargātu jūsu konfidencialitāti.",
    "New message" : "Jauna ziņa",
    "Settings" : "Iestatījumi",
    "Add folder" : "Pievienot mapi",
    "Delete account" : "Dzēst kontu",
    "Show all folders" : "Rādīt visas mapes",
    "Collapse folders" : "Sakļaut mapes",
    "Signature" : "Paraksts",
    "General" : "Vispārīgs",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Search" : "Meklēt",
    "Refresh" : "Atsvaidzināt",
    "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ja nevēlaties apmeklēt šo lapu, varat atgriezties pie <a href=\"%s\">e-pasta</a>.",
    "Continue to %s" : "Turpināt %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
